# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['blog', 'blog.management', 'blog.management.commands', 'blog.migrations']

package_data = \
{'': ['*'],
 'blog': ['locale/fr/LC_MESSAGES/*',
          'locale/it/LC_MESSAGES/*',
          'locale/pt_BR/LC_MESSAGES/*',
          'templates/*',
          'templates/blog/*']}

install_requires = \
['Django', 'lxml', 'requests', 'wagtail>=2,<3']

setup_kwargs = {
    'name': 'wagtail-blog',
    'version': '2.3.2',
    'description': 'A wordpress like blog app implemented in wagtail',
    'long_description': '# Wagtail Blog\n\n[![pipeline status](https://gitlab.com/thelabnyc/wagtail_blog/badges/master/pipeline.svg)](https://gitlab.com/thelabnyc/wagtail_blog/commits/master)\n\nA WordPress-like blog app implemented in Wagtail.\n\n# What is it\n\nAfter reimplementing WordPress-like blogs over and over again in Wagtail I decided to just make this.\nFeel free to use as is or copy it as a starting point. \nIt\'s based on the Wagtail demo blog but is closer to a standard WordPress blog style. \n\nThis is a starting point for your wagtail based blog, especially if you are migrating from Wordpress. It\'s not Wordpress and it\'s not drop in. You are expected to add your own templates and are given on a skeleton template to start from.\n\n## Features\n\n- Categories and tags with views\n- RSS\n- Basic starter templates with pagination\n- Comments\n- WordPress importer\n\n# Installation\n\nYou should start with a existing wagtail django project and have a basic understanding of Wagtail before starting.\nSee http://docs.wagtail.io\n\nTested with Wagtail 2.x and Django 2.2.\n\n1. `pip install wagtail-blog`\n2. Add `blog` to INSTALLED_APPS\n3. Add `url(r\'^blog/\', include(\'blog.urls\', namespace="blog")),` to urls.py\n4. `python manage.py migrate`\n5. Override [templates](/blog/templates/blog/) as needed.\n\n## Extending\n\nWagtail blog features abstract base models. If you want to change functionality you may extend this models from `blog.abstract` and use them how you\'d like. Do not add `blog` to your INSTALLED_APPS if you do this. You\'ll need to create your own logic to gather context variables. See blog/models.py for an example of this. Wagtail blog doesn\'t support any way to "drop in" the blog app and just make minor changes to models.\n\n# Settings\n\n- `BLOG_PAGINATION_PER_PAGE` (Default 10) Set to change the number of blogs per page. Set to None to disable (useful if using your own pagination implementation).\n- `BLOG_LIMIT_AUTHOR_CHOICES_GROUP` Optionally set this to limit the author field choices based on this Django Group. Otherwise it defaults to check if user is_staff. Set to a tuple to allow multiple groups.\n- `BLOG_LIMIT_AUTHOR_CHOICES_ADMIN` Set to true if limiting authors to multiple groups and want to add is_staff users as well.\n\n# Import from WordPress\n\nThe v2 API is the recommended way to import. It has a cleaner, more recent implementation that is easy to extend as needed.\nThe v1 API and xml import use an older, less maintained, codebase and are kept here just in case they are useful to anyone.\n\n## Wordpress API v2\n\nThis method works with any reasonably modern Wordpress instance and requires no changes to Wordpress and no authentication is needed. It\'s tested in both wordpress.com and privately hosted Wordpress instances.\n\n### Usage\n\nUse the Django management command `import_wordpress` and provide the slug of the Blog Index Page you wish to add the pages to. For example if you made a Blog Index Page called "blog" and wanted to import my personal wordpress.com hosted blog run:\n\n`./manage.py import_wordpress blog --url=https://public-api.wordpress.com/wp/v2/sites/davidmburke.com`\n\nNotice the special wordpress.com url schema. For a private wordpress instance it would typically look like `https://example.com/wp-json/wp/v2` instead.\n\n**Optional Arguments**\n\n- --convert-images (False) set to True to attempt converting images to Wagtail Image objects. Requires `beautifulsoup4`.\n- --create-users (False) set to True to create new users out of authors.\n\n**Extending**\n\nSee [wordpress_import.py](/blog/wordpress_import.py). This project can\'t predict how you host images or implement comments. It\'s intended to be modified to suit your project\'s needs.\n\n## JSON API Import\n\n*Legacy feature*\n\nThe import feature requires `django-contrib-comments` and `django-comments-xtd`\n\n1. Enable WordPress JSON API\n2. Create a Blog index page and note the title. Let\'s pretend my blog index page title is "blog"\n3. Run `./manage.py wordpress_to_wagtail blog --url=http://myblog.com username password` the username is your WordPress username with full access to the API. Without this you can\'t access all blog posts.\n\nThis works by getting the json data for your posts and making Wagtail pages for them. \nIt then downloads any images it finds and replaces urls to use your site instead of an external site. \nBlog authors will become Django users.\nThis is a complex process and is prone to error. You should plan to review the import code and fix some issues.\nMerge requests welcome to improve this feature.\n\n## XML file import\n\n*Legacy feature*\n\n1. Create a WordPress XML dump by selecting "export" from the "Tools" section \nof the WordPress admin page.\n2. Create a Blog index page and note the title. Let\'s pretend my blog index page title is "blog"\n3. Run `./manage.py wordpress_to_wagtail blog --xml=export.xml` where export.xml is the XML export file from your source WordPress site. \n\nThe xml importer uses the lxml library.\n\nThis feature was tested on wordpress XML exports from exactly a few sites.\nLike the import procedure above, this process is complex and prone to error.\n\n# Comments\n\ndjango-comments-xtd comments work out of the box. Just install it as directed [here](http://django-comments-xtd.readthedocs.org/en/latest/). \nCustomizing the xtd comment templates should be all you need - but feel free to review this app\'s templates which you may want to override.\n\nFeel free to contribute other comment implementations.\n\n# Development and Contributing\n\nThe included docker-compose file should make it easy to get up and running. \n\n1. Install docker and docker-compose\n2. `docker-compose up`\n3. `docker-compose run --rm web ./manage.py migrate`\n4. `docker-compose run --rm web ./manage.py createsuperuser`\n5. Log in and create a blog index page with blog pages to see a very basic implementation.\n\nPlease submit issues and merge requests only on [gitlab](https://gitlab.com/thelabnyc/wagtail_blog). The github page is a read only mirror.\n\nA good merge request should have:\n\n- Based off of the master branch. It should contain only changes that are yours and not from merging.\n- Include tests whenever possible. Are you fixing a bug? Add a test that breaks before your patch and works after.\n',
    'author': 'David Burke',
    'author_email': None,
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://gitlab.com/thelabnyc/wagtail_blog',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
